@@ -10,12 +10,16 @@ use File::HomeDir;
 use Log::Any qw/$log/;
 use Path::Tiny qw/path rootdir cwd/;
 
-our $VERSION = '0.1.5_2';
+our $VERSION = '0.1.5_3';
 our $pager;
 
 sub DBVERSION { 1 }
 sub MSWin32   { $^O eq 'MSWin32' }
 
+has debug => (
+    is => 'rw',
+);
+
 has db => (
     is      => 'ro',
     default => \&_build_db,
@@ -115,12 +119,12 @@ sub BUILD {
     my $opts = $self->opts;
 
     # For Term::ANSIColor
-    $ENV{ANSI_COLORS_DISABLED} = $opts->{no_color} || !-t STDOUT;
+    $ENV{ANSI_COLORS_DISABLED} //= $opts->{no_color} || !-t STDOUT;
 
     binmode STDIN,  ':encoding(utf8)';
     binmode STDOUT, ':encoding(utf8)';
 
-    if ( $opts->{debug} ) {
+    if ($self->debug($self->debug // $opts->{debug})) {
         require Log::Any::Adapter;
         if ( exists $INC{'Test/More.pm'} ) {
 
@@ -361,18 +365,18 @@ sub find_repo {
     my $self = shift;
     my $name = shift;
 
-    if ( $self->opts->{user_repo} ) {
-        my $repo = $self->user_repo || return;
-        return $repo;
-    }
+    return $self->user_repo if $self->opts->{user_repo};
 
-    my $root = rootdir;
-    my $try  = cwd;
+    my $try = cwd;
 
-    until ( $try eq $root ) {
+    while (1) {
         if ( -d ( my $repo = $try->child($name) ) ) {
             return $repo;
         }
+        elsif ( -f $repo ) { # inside a repo directory
+            return $try;
+        }
+        last if $try->is_rootdir;
         $try = $try->parent;
     }
 
@@ -1086,7 +1090,7 @@ App::bif - A base class for App::bif::* commands
 
 =head1 VERSION
 
-0.1.5_2 (2015-06-26)
+0.1.5_3 (2015-06-30)
 
 =head1 SYNOPSIS
 
