@@ -4,9 +4,41 @@ use warnings;
 use Bif::Mo;
 use Path::Tiny qw/cwd path/;
 
-our $VERSION = '0.1.5_2';
+our $VERSION = '0.1.5_3';
 extends 'App::bif';
 
+sub init_user_repo {
+    my $self         = shift;
+    my $keep_invalid = shift;
+
+    require File::HomeDir;
+    my $user_repo = path( File::HomeDir->my_home )->child('.bifu');
+    return if $user_repo->is_dir;
+
+    $self->new_cmd(
+        'App::bif::new::repo',
+        opts   => { config => 1, directory => $user_repo },
+        subref => sub {
+
+            # This $self is a new_repo with a valid db handle
+            my $self          = shift;
+            my $major_version = shift;
+            my $minor_version = shift;
+
+            $self->dbw->xdo(
+                insert_into => 'bifkv',
+                values      => {
+                    key      => 'keep_invalid',
+                    bool_val => $keep_invalid,
+                },
+            );
+
+            $self->new_cmd( 'App::bif::new::identity', opts => { self => 1, } )
+              ->run;
+        },
+    )->run;
+}
+
 sub run {
     my $self = shift;
     my $opts = $self->opts;
@@ -15,101 +47,46 @@ sub run {
     return $self->err( 'DirExists', 'directory exists: ' . $dir )
       if -e $dir;
 
-    require File::HomeDir;
-    my $user_repo = path( File::HomeDir->my_home )->child('.bifu');
+    $self->init_user_repo( $opts->{keep_invalid} );
 
-    $self->dispatch(
+    $self->new_cmd(
         'App::bif::new::repo',
-        {
-            opts => {
-                config    => 1,
-                directory => $user_repo,
-            },
-            subref => sub {
+        opts   => { directory => $dir },
+        subref => sub {
 
-                # This $self is a new_repo with a valid db handle
-                my $self          = shift;
-                my $major_version = shift;
-                my $minor_version = shift;
+            # This $self is a new_repo with a valid db handle
+            my $self          = shift;
+            my $major_version = shift;
+            my $minor_version = shift;
 
-                $self->dbw->xdo(
-                    insert_into => 'bifkv',
-                    values      => {
-                        key      => 'keep_invalid',
-                        bool_val => $opts->{keep_invalid},
-                    },
-                );
+            $self->dbw->xdo(
+                insert_into => 'bifkv',
+                values      => {
+                    key      => 'keep_invalid',
+                    bool_val => $opts->{keep_invalid},
+                },
+            );
 
-                $self->dispatch(
-                    'App::bif::new::identity',
-                    {
-                        opts => {
-                            %$opts,    # for global options
-                            self => 1,
-                        },
-                    }
-                );
+            $self->new_cmd(
+                'App::bif::pull::identity',
+                opts => {
+                    location => $self->user_repo,
+                    self     => 1,
+                },
+            )->run;
 
-   #                $self->end_change(
-   #                    id            => $self->new_change,
-   #                    action_format => "init",
-   #                    message => "Initialized v$major_version.$minor_version",
-   #                );
-            },
-        }
-    ) if !-d $user_repo;
-
-    $self->dispatch(
-        'App::bif::new::repo',
-        {
-            opts   => { directory => $dir },
-            subref => sub {
-
-                # This $self is a new_repo with a valid db handle
-                my $self          = shift;
-                my $major_version = shift;
-                my $minor_version = shift;
-
-                $self->dbw->xdo(
-                    insert_into => 'bifkv',
-                    values      => {
-                        key      => 'keep_invalid',
-                        bool_val => $opts->{keep_invalid},
-                    },
-                );
-
-                $self->dispatch(
-                    'App::bif::pull::identity',
-                    {
-                        opts => {
-                            %$opts,    # for global options
-                            location => $user_repo,
-                            self     => 1,
-                        },
-                    },
-                );
-
-   #                $self->end_change(
-   #                    id            => $self->new_change,
-   #                    action_format => "init",
-   #                    message => "Initialized v$major_version.$minor_version",
-   #                );
-
-                $self->dispatch(
-                    'App::bif::new::hub',
-                    {
-                        opts => {
-                            %$opts,    # for global options
-                            name      => $opts->{name},
-                            title     => $opts->{name},
-                            locations => [ $opts->{location} || $dir ],
-                            default   => 1,
-                        },
-                    }
-                ) if $opts->{name};
-            },
+            $self->new_cmd(
+                'App::bif::new::hub',
+                opts => {
+                    name      => $opts->{name},
+                    title     => $opts->{name},
+                    locations => [ $opts->{location} || $dir ],
+                    default   => 1,
+                }
+              )->run
+              if $opts->{name};
         },
-    );
+    )->run;
 
     return $self->ok('Init');
 }
@@ -125,7 +102,7 @@ bif-init - initialize a new bif repository
 
 =head1 VERSION
 
-0.1.5_2 (2015-06-26)
+0.1.5_3 (2015-06-30)
 
 =head1 SYNOPSIS
 
