@@ -7,7 +7,7 @@ use Config::Tiny;
 use Log::Any '$log';
 use Path::Tiny qw/path tempdir/;
 
-our $VERSION = '0.1.5_2';
+our $VERSION = '0.1.5_3';
 extends 'App::bif';
 
 has subref => ( is => 'ro', );
@@ -23,8 +23,9 @@ sub run {
     $opts->{directory}->parent->mkpath;
 
     my $tempdir = tempdir(
-        DIR     => $opts->{directory}->parent,
-        CLEANUP => !$opts->{debug},
+        CLEANUP  => !$opts->{debug},
+        DIR      => $opts->{directory}->parent,
+        TEMPLATE => 'bif-new-repo-XXXXXX',
     );
     $log->debug( 'init: tmpdir ' . $tempdir );
 
@@ -77,9 +78,8 @@ sub run {
         $conf->write( $tempdir->child('config') );
     }
 
-    # We don't care if this fails as it is just a convenience for being
-    # able to run commands inside a repo.
-    symlink( '.', $tempdir->child('.bif') ) unless $self->MSWin32;
+    # Mark this as a repo for convenience
+    $tempdir->child('.bif')->touch;
 
     $tempdir->move( $opts->{directory} )
       || return $self->err( 'Rename',
@@ -103,7 +103,7 @@ bif-new-repo -  create an empty repository
 
 =head1 VERSION
 
-0.1.5_2 (2015-06-26)
+0.1.5_3 (2015-06-30)
 
 =head1 SYNOPSIS
 
