@@ -7,7 +7,7 @@ use DBIx::ThinSQL qw/ sq /;
 use Time::Piece;
 use Time::Seconds;
 
-our $VERSION = '0.1.5_2';
+our $VERSION = '0.1.5_3';
 extends 'App::bif';
 
 sub _build {
@@ -54,7 +54,7 @@ sub _build {
         }
 
         push( @columns,
-                " printf('%0.2d:%0.2d', "
+                " printf('%d:%0.2d', "
               . " SUM(col$i) / 3600, "
               . " (SUM(col$i) - 3600 * (SUM(col$i) / 3600)) / 60 "
               . " ) AS col$i" );
@@ -108,7 +108,12 @@ sub _build {
             push( @headers, $start->strftime('%Y-%m') );
         }
         elsif ( $type eq 'week' ) {
-            push( @headers, $start->strftime('%G-W%V') );
+
+            # Time::Piece's %V does not work under windows, so use the
+            # ->method() calls instead. See
+            # https://rt.cpan.org/Public/Bug/Display.html?id=105507
+            push( @headers,
+                sprintf( '%0.4d-W%0.2d', $start->year, $start->week ) );
         }
         elsif ( $type eq 'day' ) {
             push( @headers, $start->strftime('%Y-%m-%d') );
@@ -220,7 +225,7 @@ bif-show-timesheet - display time worked per project
 
 =head1 VERSION
 
-0.1.5_2 (2015-06-26)
+0.1.5_3 (2015-06-30)
 
 =head1 SYNOPSIS
 
