@@ -8,7 +8,7 @@ use Coro::Handle;
 use Log::Any '$log';
 use Sys::Cmd qw/spawn/;
 
-our $VERSION = '0.1.5_2';
+our $VERSION = '0.1.5_3';
 extends 'Bif::Sync';
 
 has name => (
@@ -54,10 +54,15 @@ sub BUILD {
         );
     }
     else {
-        my @bifsync = ('bifsync');
-        if ( $^O eq 'MSWin32' ) {
-            require Path::Tiny;
-            @bifsync = ( $^X, Path::Tiny::path($0)->parent->child('bifsync') );
+        my @bifsync;
+        if ($main::BIF_BIFSYNC) { # set by t/lib/Test/Bif.pm (for Win32 tests)
+            @bifsync = ( $^X, $main::BIF_BIFSYNC );
+        }
+        elsif ( $^O eq 'MSWin32' ) { # Assume bifsync next to bif
+            @bifsync = ( $^X, Path::Tiny::path($0)->parent->child('bifsync'));
+        }
+        else {
+            @bifsync = ('bifsync'); # rest of world can use PATH
         }
 
         $self->child(
@@ -334,6 +339,7 @@ sub cleanup_errors {
     my $self = shift;
     return unless $self->stderr_watcher;
     $self->stderr_watcher(undef);
+    return if $^O eq 'MSWin32';
 
     my $name   = $self->name;
     my $child  = $self->child or return;
@@ -387,7 +393,7 @@ Bif::Sync::Client - client for communication with a bif hub
 
 =head1 VERSION
 
-0.1.5_2 (2015-06-26)
+0.1.5_3 (2015-06-30)
 
 =head1 SYNOPSIS
 
