@@ -36,20 +36,27 @@ our $VERBOSE;
 our $SRC_DIR = path(__FILE__)->parent(4)->absolute;
 
 $main::BIF_SHARE_DIR = $SRC_DIR->child('share');
+$main::BIF_BIFSYNC   = $SRC_DIR->child( 'tbin', 'bifsync' );
 $main::BIF_DB_NOSYNC = 1;
 
 # Ensure that our test bifsync is found by tests
 die "Cannot find test bifsync" unless -e $SRC_DIR->child(qw/tbin bifsync/);
-$ENV{PATH} = $SRC_DIR->child('tbin') . ':' . $ENV{PATH};
+
+my $sep = $^O eq 'MSWin32' ? ';' : ':';
+
+$ENV{PATH} = $SRC_DIR->child('tbin') . $sep . $ENV{PATH};
 
 sub run_in_tempdir (&) {
     my $sub = shift;
-    my $tmp = Path::Tiny->tempdir( DIR => $ENV{TMPDIR}, CLEANUP => 1 );
-    Test::More::diag("\n$tmp");
+    my $tmp = Path::Tiny->tempdir(
+        CLEANUP  => 1,
+        DIR      => $ENV{TMPDIR},
+        TEMPLATE => 'bif-test-XXXXXXXX'
+    );
 
     {
-        $log->debug("cd $tmp");
         local $CWD = $tmp;
+        Test::More::note("\n$tmp");
         local $ENV{HOME} = $tmp;    # Don't use the testers HOME
         $sub->();
     }
@@ -68,7 +75,7 @@ sub bif {
         open( STDOUT,  '>',  'stdout.txt' ) or die "open: $!";
     }
 
-    Test::More::diag("bif @bif");
+    Test::More::note("bif @bif");
 
     my $result = eval {
         my ( $class, $opts ) = class_optargs( 'App::bif', @bif );
@@ -113,7 +120,7 @@ sub bifsync {
         open( STDOUT,  '>',  'stdout.txt' ) or die "open: $!";
     }
 
-    Test::More::diag("bifsync @_");
+    Test::More::note("bifsync @_");
 
     my $result = eval {
         my ( $class, $opts ) = class_optargs( 'App::bifsync', @_ );
@@ -134,8 +141,8 @@ sub bifsync {
 
 sub bifcheck {
     my $res = eval { bif('check') };
+    Test::More::note $@ if $@;
     Test::More::isa_ok( $res, 'Bif::OK::Check' );
-    Test::More::diag $@ if $@;
 }
 
 my $change = 0;
